import { jsx, Fragment } from 'react/jsx-runtime';
import { datadogRum } from '@datadog/browser-rum';
import { useEffect } from 'react';

var DEFAULT_REPLAY_SAMPLE_RATE = 100;

var DEFAULT_SAMPLE_RATE = 100;

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

function filterByDefined(value) {
    return typeof value !== 'undefined';
}

function filterByUndefined(value) {
    return !filterByDefined(value);
}

var OBJECT_TYPE_ERROR = new Error('Expected value to be an object.');

function parseStringifiedObject(str) {
    var parsedStr = JSON.parse(str);
    if (typeof parsedStr !== 'object' || parsedStr === null) {
        throw OBJECT_TYPE_ERROR;
    }
    return parsedStr;
}

var DEFAULT_USER = {};
function useUser(user) {
    var _a = user !== null && user !== void 0 ? user : DEFAULT_USER, email = _a.email, id = _a.id, name = _a.name, restUser = __rest(_a, ["email", "id", "name"]);
    var restUserStr = JSON.stringify(restUser);
    useEffect(function () {
        var restUserParsed = parseStringifiedObject(restUserStr);
        var newUser = __assign(__assign({}, restUserParsed), { email: email, id: id, name: name });
        if (Object.values(newUser).every(filterByUndefined)) {
            return;
        }
        datadogRum.setUser(newUser);
        return function () {
            datadogRum.removeUser();
        };
    }, [email, id, name, restUserStr]);
}

var FIRST_ITEM = 0;
function useDatadog(_a) {
    var actionNameAttribute = _a.actionNameAttribute, allowedTracingOrigins = _a.allowedTracingOrigins, applicationId = _a.applicationId, beforeSend = _a.beforeSend, clientToken = _a.clientToken, defaultPrivacyLevel = _a.defaultPrivacyLevel, enableExperimentalFeatures = _a.enableExperimentalFeatures, _b = _a.enabled, enabled = _b === void 0 ? true : _b, env = _a.env, internalMonitoringApiKey = _a.internalMonitoringApiKey, proxyUrl = _a.proxyUrl, _c = _a.replaySampleRate, replaySampleRate = _c === void 0 ? DEFAULT_REPLAY_SAMPLE_RATE : _c, replica = _a.replica, _d = _a.sampleRate, sampleRate = _d === void 0 ? DEFAULT_SAMPLE_RATE : _d, service = _a.service, _e = _a.sessionReplayRecording, sessionReplayRecording = _e === void 0 ? true : _e, silentMultipleInit = _a.silentMultipleInit, _f = _a.site, site = _f === void 0 ? 'datadoghq.com' : _f, _g = _a.trackInteractions, trackInteractions = _g === void 0 ? true : _g, trackSessionAcrossSubdomains = _a.trackSessionAcrossSubdomains, trackViewsManually = _a.trackViewsManually, useCrossSiteSessionCookie = _a.useCrossSiteSessionCookie, useSecureSessionCookie = _a.useSecureSessionCookie, user = _a.user, version = _a.version;
    useEffect(function () {
        if (!enabled) {
            return;
        }
        datadogRum.init({
            actionNameAttribute: actionNameAttribute,
            allowedTracingOrigins: allowedTracingOrigins === null || allowedTracingOrigins === void 0 ? void 0 : allowedTracingOrigins.slice(FIRST_ITEM),
            applicationId: applicationId,
            beforeSend: beforeSend,
            clientToken: clientToken,
            defaultPrivacyLevel: defaultPrivacyLevel,
            enableExperimentalFeatures: enableExperimentalFeatures === null || enableExperimentalFeatures === void 0 ? void 0 : enableExperimentalFeatures.slice(FIRST_ITEM),
            env: env,
            internalMonitoringApiKey: internalMonitoringApiKey,
            proxyUrl: proxyUrl,
            replaySampleRate: replaySampleRate,
            replica: replica,
            sampleRate: sampleRate,
            service: service,
            silentMultipleInit: silentMultipleInit,
            site: site,
            trackInteractions: trackInteractions,
            trackSessionAcrossSubdomains: trackSessionAcrossSubdomains,
            trackViewsManually: trackViewsManually,
            useCrossSiteSessionCookie: useCrossSiteSessionCookie,
            useSecureSessionCookie: useSecureSessionCookie,
            version: version,
        });
    }, [
        actionNameAttribute,
        allowedTracingOrigins,
        applicationId,
        beforeSend,
        clientToken,
        defaultPrivacyLevel,
        enableExperimentalFeatures,
        enabled,
        env,
        internalMonitoringApiKey,
        proxyUrl,
        replaySampleRate,
        replica,
        sampleRate,
        service,
        silentMultipleInit,
        site,
        trackInteractions,
        trackSessionAcrossSubdomains,
        trackViewsManually,
        useCrossSiteSessionCookie,
        useSecureSessionCookie,
        version,
    ]);
    useEffect(function () {
        if (!enabled || !sessionReplayRecording) {
            return;
        }
        datadogRum.startSessionReplayRecording();
        return function () {
            datadogRum.stopSessionReplayRecording();
        };
    }, [enabled, sessionReplayRecording]);
    useUser(user);
}

function Datadog(_a) {
    var actionNameAttribute = _a.actionNameAttribute, allowedTracingOrigins = _a.allowedTracingOrigins, applicationId = _a.applicationId, beforeSend = _a.beforeSend, children = _a.children, clientToken = _a.clientToken, defaultPrivacyLevel = _a.defaultPrivacyLevel, enableExperimentalFeatures = _a.enableExperimentalFeatures, enabled = _a.enabled, env = _a.env, internalMonitoringApiKey = _a.internalMonitoringApiKey, proxyUrl = _a.proxyUrl, replaySampleRate = _a.replaySampleRate, replica = _a.replica, sampleRate = _a.sampleRate, service = _a.service, sessionReplayRecording = _a.sessionReplayRecording, silentMultipleInit = _a.silentMultipleInit, site = _a.site, trackInteractions = _a.trackInteractions, trackSessionAcrossSubdomains = _a.trackSessionAcrossSubdomains, trackViewsManually = _a.trackViewsManually, useCrossSiteSessionCookie = _a.useCrossSiteSessionCookie, useSecureSessionCookie = _a.useSecureSessionCookie, user = _a.user, version = _a.version;
    useDatadog({
        actionNameAttribute: actionNameAttribute,
        allowedTracingOrigins: allowedTracingOrigins,
        applicationId: applicationId,
        beforeSend: beforeSend,
        clientToken: clientToken,
        defaultPrivacyLevel: defaultPrivacyLevel,
        enableExperimentalFeatures: enableExperimentalFeatures,
        enabled: enabled,
        env: env,
        internalMonitoringApiKey: internalMonitoringApiKey,
        proxyUrl: proxyUrl,
        replaySampleRate: replaySampleRate,
        replica: replica,
        sampleRate: sampleRate,
        service: service,
        sessionReplayRecording: sessionReplayRecording,
        silentMultipleInit: silentMultipleInit,
        site: site,
        trackInteractions: trackInteractions,
        trackSessionAcrossSubdomains: trackSessionAcrossSubdomains,
        trackViewsManually: trackViewsManually,
        useCrossSiteSessionCookie: useCrossSiteSessionCookie,
        useSecureSessionCookie: useSecureSessionCookie,
        user: user,
        version: version,
    });
    return jsx(Fragment, { children: children }, void 0);
}

function DatadogPrivacy(_a) {
    var children = _a.children, level = _a.level;
    return (jsx("span", __assign({ className: "dd-privacy-" + level, "data-dd-privacy": level }, { children: children }), void 0));
}

function DatadogAllow(_a) {
    var children = _a.children;
    return jsx(DatadogPrivacy, __assign({ level: "allow" }, { children: children }), void 0);
}
function DataDogAllow(_a) {
    var children = _a.children;
    console.warn('The `DataDogAllow` component is deprecated. Please use `DatadogAllow` instead.');
    return jsx(DatadogAllow, { children: children }, void 0);
}

function DatadogHidden(_a) {
    var children = _a.children;
    return jsx(DatadogPrivacy, __assign({ level: "hidden" }, { children: children }), void 0);
}
function DataDogHidden(_a) {
    var children = _a.children;
    console.warn('The `DataDogHidden` component is deprecated. Please use `DatadogHidden` instead.');
    return jsx(DatadogHidden, { children: children }, void 0);
}

function DatadogMask(_a) {
    var children = _a.children;
    return jsx(DatadogPrivacy, __assign({ level: "mask" }, { children: children }), void 0);
}
function DataDogMask(_a) {
    var children = _a.children;
    console.warn('The `DataDogMask` component is deprecated. Please use `DatadogMask` instead.');
    return jsx(DatadogMask, { children: children }, void 0);
}

function DatadogMaskUserInput(_a) {
    var children = _a.children;
    return jsx(DatadogPrivacy, __assign({ level: "mask-user-input" }, { children: children }), void 0);
}
function DataDogMaskUserInput(_a) {
    var children = _a.children;
    console.warn('The `DataDogMaskUserInput` component is deprecated. Please use `DatadogMaskUserInput` instead.');
    return jsx(DatadogMaskUserInput, { children: children }, void 0);
}

function useDatadogRum() {
    return datadogRum;
}
function useDataDogRum() {
    console.warn('`useDataDogRum` is deprecated. Please use `useDatadogRum` instead.');
    return useDatadogRum();
}

export { DataDogAllow, DataDogHidden, DataDogMask, DataDogMaskUserInput, DatadogAllow, DatadogHidden, DatadogMask, DatadogMaskUserInput, Datadog as default, useDataDogRum, useDatadogRum };
